Fits a penalized gamma augmentation model via cross fitting and returns vector of length n of out of sample predictions on the link scale from cross fitting
HDtweedie_kfold_aug(
x,
y,
trt,
wts = NULL,
K = 10,
p = 1.5,
interactions = FALSE
)an n x p matrix of covariates for the zero part data, where each row is an observation and each column is a predictor. MUST be ordered such that the first n_s rows align with the observations in x_s and s
a length n vector of responses taking positive values
a length n vector of treatment variables with 1 indicating treatment and -1 indicating control
a length n vector of sample weights
number of folds for cross fitting
tweedie mixing parameter. See HDtweedie for details
boolean variable of whether or not to fit model with interactions. For predictions, interactions will be integrated out